Class: Google::Cloud::AlloyDB::V1::Instance::InstanceNetworkConfig
- Inherits:
-
Object
- Object
- Google::Cloud::AlloyDB::V1::Instance::InstanceNetworkConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/alloydb/v1/resources.rb
Overview
Metadata related to instance-level network configuration.
Defined Under Namespace
Classes: AuthorizedNetwork
Instance Attribute Summary collapse
-
#allocated_ip_range_override ⇒ ::String
Optional.
-
#authorized_external_networks ⇒ ::Array<::Google::Cloud::AlloyDB::V1::Instance::InstanceNetworkConfig::AuthorizedNetwork>
Optional.
-
#enable_outbound_public_ip ⇒ ::Boolean
Optional.
-
#enable_public_ip ⇒ ::Boolean
Optional.
-
#network ⇒ ::String
readonly
Output only.
Instance Attribute Details
#allocated_ip_range_override ⇒ ::String
Returns Optional. Name of the allocated IP range for the private IP AlloyDB instance, for example: "google-managed-services-default". If set, the instance IPs will be created from this allocated range and will override the IP range used by the parent cluster. The range name must comply with RFC 1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z?.
1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1118 class InstanceNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AuthorizedNetwork contains metadata for an authorized network. # @!attribute [rw] cidr_range # @return [::String] # CIDR range for one authorzied network of the instance. class AuthorizedNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#authorized_external_networks ⇒ ::Array<::Google::Cloud::AlloyDB::V1::Instance::InstanceNetworkConfig::AuthorizedNetwork>
Returns Optional. A list of external network authorized to access this instance.
1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1118 class InstanceNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AuthorizedNetwork contains metadata for an authorized network. # @!attribute [rw] cidr_range # @return [::String] # CIDR range for one authorzied network of the instance. class AuthorizedNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enable_outbound_public_ip ⇒ ::Boolean
Returns Optional. Enabling an outbound public IP address to support a database server sending requests out into the internet.
1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1118 class InstanceNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AuthorizedNetwork contains metadata for an authorized network. # @!attribute [rw] cidr_range # @return [::String] # CIDR range for one authorzied network of the instance. class AuthorizedNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enable_public_ip ⇒ ::Boolean
Returns Optional. Enabling public ip for the instance.
1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1118 class InstanceNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AuthorizedNetwork contains metadata for an authorized network. # @!attribute [rw] cidr_range # @return [::String] # CIDR range for one authorzied network of the instance. class AuthorizedNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#network ⇒ ::String (readonly)
Returns Output only. The resource link for the VPC network in which instance
resources are created and from which they are accessible via Private IP.
This will be the same value as the parent cluster's network. It is
specified in the form: //
projects/{project_number}/global/networks/{network_id}.
1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1118 class InstanceNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AuthorizedNetwork contains metadata for an authorized network. # @!attribute [rw] cidr_range # @return [::String] # CIDR range for one authorzied network of the instance. class AuthorizedNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |