Class: Google::Cloud::AlloyDB::V1::Instance::PscInstanceConfig
- Inherits:
-
Object
- Object
- Google::Cloud::AlloyDB::V1::Instance::PscInstanceConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/alloydb/v1/resources.rb
Overview
PscInstanceConfig contains PSC related configuration at an instance level.
Instance Attribute Summary collapse
-
#allowed_consumer_projects ⇒ ::Array<::String>
Optional.
-
#psc_auto_connections ⇒ ::Array<::Google::Cloud::AlloyDB::V1::Instance::PscAutoConnectionConfig>
Optional.
-
#psc_dns_name ⇒ ::String
readonly
Output only.
-
#psc_interface_configs ⇒ ::Array<::Google::Cloud::AlloyDB::V1::Instance::PscInterfaceConfig>
Optional.
-
#service_attachment_link ⇒ ::String
readonly
Output only.
Instance Attribute Details
#allowed_consumer_projects ⇒ ::Array<::String>
Returns Optional. List of consumer projects that are allowed to create PSC endpoints to service-attachments to this instance.
1086 1087 1088 1089 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1086 class PscInstanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#psc_auto_connections ⇒ ::Array<::Google::Cloud::AlloyDB::V1::Instance::PscAutoConnectionConfig>
Returns Optional. Configurations for setting up PSC service automation.
1086 1087 1088 1089 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1086 class PscInstanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#psc_dns_name ⇒ ::String (readonly)
Returns Output only. The DNS name of the instance for PSC connectivity.
Name convention:
1086 1087 1088 1089 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1086 class PscInstanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#psc_interface_configs ⇒ ::Array<::Google::Cloud::AlloyDB::V1::Instance::PscInterfaceConfig>
Returns Optional. Configurations for setting up PSC interfaces attached to the instance which are used for outbound connectivity. Only primary instances can have PSC interface attached. Currently we only support 0 or 1 PSC interface.
1086 1087 1088 1089 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1086 class PscInstanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_attachment_link ⇒ ::String (readonly)
Returns Output only. The service attachment created when Private
Service Connect (PSC) is enabled for the instance.
The name of the resource will be in the format of
projects/<alloydb-tenant-project-number>/regions/<region-name>/serviceAttachments/<service-attachment-name>.
1086 1087 1088 1089 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1086 class PscInstanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |