Class: Google::Cloud::AlloyDB::V1::Cluster::DataplexConfig
- Inherits:
-
Object
- Object
- Google::Cloud::AlloyDB::V1::Cluster::DataplexConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/alloydb/v1/resources.rb
Overview
Configuration for Dataplex integration.
Instance Attribute Summary collapse
-
#enabled ⇒ ::Boolean
Dataplex is enabled by default for resources such as clusters and instances.
Instance Attribute Details
#enabled ⇒ ::Boolean
Returns Dataplex is enabled by default for resources such as clusters and instances. This flag controls the integration of AlloyDB PG resources (like databases, schemas, and tables) with Dataplex.".
640 641 642 643 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 640 class DataplexConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |