Class: Google::Cloud::AlloyDB::V1::User
- Inherits:
-
Object
- Object
- Google::Cloud::AlloyDB::V1::User
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/alloydb/v1/resources.rb
Overview
Message describing User object.
Defined Under Namespace
Modules: UserType
Instance Attribute Summary collapse
-
#database_roles ⇒ ::Array<::String>
Optional.
-
#keep_extra_roles ⇒ ::Boolean
Input only.
-
#name ⇒ ::String
readonly
Output only.
-
#password ⇒ ::String
Input only.
-
#user_type ⇒ ::Google::Cloud::AlloyDB::V1::User::UserType
Optional.
Instance Attribute Details
#database_roles ⇒ ::Array<::String>
Returns Optional. List of database roles this user has. The database role strings are subject to the PostgreSQL naming conventions.
1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1624 class User include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that details the user type. module UserType # Unspecified user type. USER_TYPE_UNSPECIFIED = 0 # The default user type that authenticates via password-based # authentication. ALLOYDB_BUILT_IN = 1 # Database user that can authenticate via IAM-Based authentication. ALLOYDB_IAM_USER = 2 end end |
#keep_extra_roles ⇒ ::Boolean
Returns Input only. If the user already exists and it has additional roles, keep them granted.
1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1624 class User include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that details the user type. module UserType # Unspecified user type. USER_TYPE_UNSPECIFIED = 0 # The default user type that authenticates via password-based # authentication. ALLOYDB_BUILT_IN = 1 # Database user that can authenticate via IAM-Based authentication. ALLOYDB_IAM_USER = 2 end end |
#name ⇒ ::String (readonly)
Returns Output only. Name of the resource in the form of projects/{project}/locations/{location}/cluster/{cluster}/users/{user}.
1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1624 class User include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that details the user type. module UserType # Unspecified user type. USER_TYPE_UNSPECIFIED = 0 # The default user type that authenticates via password-based # authentication. ALLOYDB_BUILT_IN = 1 # Database user that can authenticate via IAM-Based authentication. ALLOYDB_IAM_USER = 2 end end |
#password ⇒ ::String
Returns Input only. Password for the user.
1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1624 class User include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that details the user type. module UserType # Unspecified user type. USER_TYPE_UNSPECIFIED = 0 # The default user type that authenticates via password-based # authentication. ALLOYDB_BUILT_IN = 1 # Database user that can authenticate via IAM-Based authentication. ALLOYDB_IAM_USER = 2 end end |
#user_type ⇒ ::Google::Cloud::AlloyDB::V1::User::UserType
Returns Optional. Type of this user.
1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 |
# File 'proto_docs/google/cloud/alloydb/v1/resources.rb', line 1624 class User include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that details the user type. module UserType # Unspecified user type. USER_TYPE_UNSPECIFIED = 0 # The default user type that authenticates via password-based # authentication. ALLOYDB_BUILT_IN = 1 # Database user that can authenticate via IAM-Based authentication. ALLOYDB_IAM_USER = 2 end end |